@@ -39,27 +39,27 @@ string ConnectionToHTTP::PrepareHeaderForBrowser()
         //Uppercase for matching
         it = UpperCase(*itvec);
 
-        if( it.find( "TRANSFER-ENCODING", 0 ) == 0 )
+        if ( MatchBegin( it, "KEEP-ALIVE", 10 ) )
         {
             continue;
         }
-        else if( it.find( "KEEP-ALIVE", 0 ) == 0 )
+        else if ( MatchBegin( it, "CONNECTION", 10 ) )
         {
             continue;
         }
-        else if( it.find( "CONNECTION", 0) == 0 )
+        else if ( MatchBegin( it, "PROXY-CONNECTION", 16 ) )
         {
             continue;
         }
-        else if( it.find( "PROXY-CONNECTION", 0) == 0 )
-        {
-            continue;
-        }
-        else if( it.find( "CONTENT-LENGTH", 0) == 0 && (ContentLength == -1) )
+        else if ( MatchBegin( it, "CONTENT-LENGTH", 14 ) && (ContentLength == -1) )
         {
             //Do not pass invalid Content-Length
             continue;
         }
+        else if ( MatchBegin( it, "TRANSFER-ENCODING", 17 ) )
+        {
+            continue;
+        }
 
         header += *itvec;
         header += "\r\n";
@@ -110,7 +110,7 @@ int ConnectionToHTTP::AnalyseHeaderLine( string &RequestT )
         //Uppercase for matching
         string RequestU = UpperCase(RequestT);
 
-        if ( RequestU.find("CONTENT-LENGTH: ", 0) == 0 )
+        if ( MatchBegin( RequestU, "CONTENT-LENGTH: ", 16 ) )
         {
             if ( RequestU.find_first_not_of("0123456789", 16) != string::npos )
             {
@@ -131,16 +131,31 @@ int ConnectionToHTTP::AnalyseHeaderLine( string &RequestT )
             return 0;
         }
 
-        if ( RequestU.find("CONNECTION: KEEP-ALIVE", 0) != string::npos )
+        if ( MatchSubstr( RequestU, "CONNECTION: KEEP-ALIVE", -1 ) )
         {
-            KeepAlive = true;
+            IsKeepAlive = true;
 
             return 0;
         }
 
-        if ( RequestU.find("CONTENT-TYPE: IMAGE/", 0) != string::npos )
+        if ( MatchBegin( RequestU, "CONTENT-TYPE: IMAGE/", 20 ) )
         {
             IsImage = true;
+
+            return 0;
+        }
+
+        if ( MatchBegin( RequestU, "TRANSFER-ENCODING: CHUNKED", 26 ) )
+        {
+            IsChunked = true;
+
+            return 0;
+        }
+
+        if ( MatchBegin( RequestU, "TRANSFER-ENCODING: ", 19 ) )
+        {
+            //Not allowed on HTTP/1.0
+            return -232;
         }
 
     }//End >16 check
@@ -158,20 +173,25 @@ int ConnectionToHTTP::GetResponse()
     return HTMLResponse;
 }
 
-bool ConnectionToHTTP::KeepItAlive()
+bool ConnectionToHTTP::IsItKeepAlive()
 {
-    return KeepAlive;
+    return IsKeepAlive;
 }
 
-bool ConnectionToHTTP::ContentImage()
+bool ConnectionToHTTP::IsItImage()
 {
     return IsImage;
 }
 
+bool ConnectionToHTTP::IsItChunked()
+{
+    return IsChunked;
+}
+
 void ConnectionToHTTP::ClearVars()
 {
     ContentLength = -1;
-    KeepAlive = IsImage = false;
+    IsKeepAlive = IsImage = IsChunked = false;
 }
 
 
