@@ -22,6 +22,7 @@
 #include "sockethandler.h"
 #include "logfile.h"
 #include "params.h"
+#include "utils.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -43,7 +44,7 @@ string ScannerNameShort;
 bool StartScanning( int fromhandler, int tohandler, const char *FileName );
 
 virtual bool InitDatabase() = 0;
-virtual bool ReloadDatabase() = 0;
+virtual int ReloadDatabase() = 0;
 virtual void FreeDatabase() = 0;
 virtual string Scan( const char *FileName ) = 0;
 
