@@ -24,6 +24,7 @@
 #include <arpa/inet.h>
 #include <iostream>
 #include <fstream>
+#include <cstdlib>
 
 #ifndef INADDR_NONE
 #define INADDR_NONE ((unsigned long) -1)
@@ -57,6 +58,7 @@ void Params::SetDefaults()
     SetConfig("KEEPBACKBUFFER",	"200000");
     SetConfig("KEEPBACKTIME",	"5");
     SetConfig("TRICKLING",	"30");
+    SetConfig("TRICKLINGBYTES",	"1");
     SetConfig("WHITELISTFIRST",	"true");
     SetConfig("WHITELIST",	WHITELISTFILE);
     SetConfig("BLACKLIST",	BLACKLISTFILE);
@@ -75,14 +77,16 @@ void Params::SetDefaults()
     SetConfig("MAXDOWNLOADSIZE","0");
     SetConfig("SCANNERTIMEOUT",	"10");
     SetConfig("IGNOREVIRUS",	"");
+    SetConfig("DISABLELOCKINGFOR","ClamAV:BinHex ClamAV:PDF ClamAV:ZIP");
 //SCANNERS
     SetConfig("ENABLECLAMLIB","false");
         SetConfig("CLAMDBDIR","");
         SetConfig("CLAMBLOCKBROKEN","false");
         SetConfig("CLAMBLOCKMAX","false");
         SetConfig("CLAMBLOCKENCRYPTED","false");
-        SetConfig("CLAMMAXFILES","1000");
-        SetConfig("CLAMMAXFILESIZE","10");
+        SetConfig("CLAMMAXSCANSIZE","20");
+        SetConfig("CLAMMAXFILES","50");
+        SetConfig("CLAMMAXFILESIZE","100");
         SetConfig("CLAMMAXRECURSION","8");
         SetConfig("CLAMMAXRATIO","250");
     SetConfig("ENABLECLAMD","false");
@@ -97,11 +101,12 @@ void Params::SetDefaults()
     SetConfig("ENABLEFPROT","false");
         SetConfig("FPROTPORT","10200");
         SetConfig("FPROTSERVER","127.0.0.1");
+        SetConfig("FPROTOPTIONS","");
     SetConfig("ENABLENOD32","false");
         SetConfig("NOD32SOCKET","/tmp/nod32d.sock");
         SetConfig("NOD32VERSION","25");
     SetConfig("ENABLETROPHIE","false");
-        SetConfig("TROPHIEMAXFILES","1000");
+        SetConfig("TROPHIEMAXFILES","50");
         SetConfig("TROPHIEMAXFILESIZE","10");
         SetConfig("TROPHIEMAXRATIO","250");
     SetConfig("ENABLESOPHIE","false");
@@ -112,6 +117,13 @@ void Params::SetDefaults()
         SetConfig("AVASTPORT","5036");
     SetConfig("ENABLEARCAVIR","false");
         SetConfig("ARCAVIRSOCKET","/var/run/arcavird.socket");
+        SetConfig("ARCAVIRVERSION","2007");
+    SetConfig("ENABLEDRWEB","false");
+        SetConfig("DRWEBSOCKET","/var/drweb/run/.daemon");
+        SetConfig("DRWEBSERVER","");
+        SetConfig("DRWEBPORT","3000");
+        SetConfig("DRWEBHEURISTIC","true");
+        SetConfig("DRWEBMALWARE","true");
 }
 
 bool Params::ReadConfig( string file )
@@ -412,6 +424,11 @@ bool Params::TestConfig()
         cout << "Invalid Config: Invalid PARENTPROXY/PARENTPORT" << endl;
         return false;
     }
+    if ( Params::GetConfigInt("TRICKLING") > 0 && Params::GetConfigInt("TRICKLINGBYTES") < 1 )
+    {
+        cout << "Invalid Config: TRICKLINGBYTES needs to be greater than 0" << endl;
+        return false;
+    }
 
     return true;
 }
